#include "startuptools.h"
#include <QDir>
#include <QFile>
#include <QFileInfo>
#include <QFileInfoList>
#include <QDebug>
#include <QJsonObject>
#include <QJsonDocument>
#include <QJsonValue>
#include <stdlib.h>

const QString CONFIGPATH = "/usr/share/kylin-asrassistant/config/";
const QString KEYWORD = "keyword";
const QString VALUEWORD = "path";
const QString BREAKSEP = ";";

StartUpTools *StartUpTools::getInstance()
{
    static StartUpTools instance;
    return &instance;
}


void StartUpTools::loadConfig()
{
    m_map.clear();
    QDir configDir(CONFIGPATH);
    if (!configDir.exists()) {
        qCritical() << "Profile path error!";
        return;
    }
    QFileInfoList fileInfoList = configDir.entryInfoList(QDir::Files);
    for (auto fileInfo : fileInfoList) {
        if (fileInfo.isFile()) {
            QString currentFileName = fileInfo.fileName();
            qInfo() << "Load the profile " << currentFileName;
            QFile *file = new QFile(CONFIGPATH + currentFileName);
            if (!file->open(QIODevice::ReadOnly)) {
                // 打开文件失败
                qCritical() << "fail to open file " << currentFileName;
                delete file;
                continue;
            }

            QByteArray data = file->readAll();
            QString strInfoAll = data;
            if (strInfoAll.isEmpty()) {
                qInfo() << currentFileName << " isEmpty";
                continue;
            }
            QByteArray infoJsonBuf = strInfoAll.toUtf8();
            QJsonDocument infoJsonDoc = QJsonDocument::fromJson(infoJsonBuf);
            QJsonObject infoJsonObj = infoJsonDoc.object();
            QString allKey = infoJsonObj.value(KEYWORD).toString();
            QString value = infoJsonObj.value(VALUEWORD).toString();
            QStringList keyList = allKey.split(BREAKSEP);
            for (auto key : keyList) {
                m_map.insert(key, value);
            }
            file->close();
            delete file;
        }
    }
    if (m_map.isEmpty()) {
        qWarning() << "There are no awakening keywords currently!";
    }
}

QString StartUpTools::findKey(const QString &key)
{
    if (!m_map.contains(key)) {
        return QString("");
    }
    return m_map.find(key).value();
}

void StartUpTools::startUp(const QString &path)
{
    qInfo() << "Start pulling up the app";
    QString command = path + " &";
    system(command.toStdString().c_str());
}